Learn R Programming

WRS2 (version 0.4-0)

t1way: A heteroscedastic one-way ANOVA for trimmed means.

Description

The t1way function computes a one-way ANOVA for the medians. Homoscedasticity assumption not required. It uses a generalization of Welch's method. Corresponding post hoc tests can be performed using lincon.

Usage

t1way(formula, data, tr = 0.2) lincon(formula, data, tr = 0.2)

Arguments

formula
an object of class formula.
data
an optional data frame for the input data.
tr
trim level for the mean.

Value

t1way returns an object of class "t1way" containing:
test
value of the test statistic (F-statistic)
df1
degrees of freedom
df2
degrees of freedom
p.value
p-value
call
function call
lincon returns an object of class "mcp1" containing:
comp
inference for all pairwise comparisons
fnames
names of the factor levels

Details

In the post hoc computations, confidence intervals are adjusted to control FWE, but p-values are not adjusted to control FWE.

References

Wilcox, R. (2012). Introduction to Robust Estimation and Hypothesis Testing (3rd ed.). Elsevier.

See Also

med1way,t1waybt

Examples

Run this code
t1way(libido ~ dose, data = viagra)

## post hoc tests
lincon(libido ~ dose, data = viagra)

Run the code above in your browser using DataLab