Learn R Programming

WRS2 (version 0.4-0)

yuend: Paired samples $t$-test on trimmed means.

Description

The function yuen performs Yuen's test for trimmed means, yuenbt is a bootstrap version of it. The pb2gen function performs a t-test based on various robust estimators.

Usage

yuend(x, y, tr = 0.2)

Arguments

x
an numeric vector of data values (e.g. for time 1).
y
an numeric vector of data values (e.g. for time 2).
tr
trim level for the means.

Value

Returns an object of class "yuen" containing:
test
value of the test statistic (t-statistic)
p.value
p-value
conf.int
confidence interval
df
degress of freedom
diff
trimmed mean difference
call
function call

Details

The test statistic is a paired samples generalization of Yuen's independent samples t-test on trimmed means.

References

Wilcox, R. (2012). Introduction to Robust Estimation and Hypothesis Testing (3rd ed.). Elsevier.

See Also

yuen

Examples

Run this code
## Cholesterol data from Wilcox (2012, p. 197)
before <- c(190, 210, 300,240, 280, 170, 280, 250, 240, 220)
after <- c(210, 210, 340, 190, 260, 180, 200, 220, 230, 200)
yuend(before, after)

Run the code above in your browser using DataLab